# Flux

Types:

```python
from flux_client.types import ClassifyResponse
```

Methods:

- <code title="post /classify">client.<a href="./src/flux_client/_client.py">classify</a>(\*\*<a href="src/flux_client/types/top_level_classify_params.py">params</a>) -> <a href="./src/flux_client/types/classify_response.py">ClassifyResponse</a></code>

# Root

Types:

```python
from flux_client.types import RootRetrieveResponse
```

Methods:

- <code title="get /">client.root.<a href="./src/flux_client/resources/root.py">retrieve</a>() -> str</code>

# Classifications

Types:

```python
from flux_client.types import ClassificationResponse
```
